==> OpenPatricianModel-0.9.0-RC1-sources.jar: ch/sahits/game/openpatrician/model/ship/impl/Cog.java <==
package ch.sahits.game.openpatrician.model.ship.impl;

import ch.sahits.game.openpatrician.model.ship.ShipProperties;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.Prototype;
import ch.sahits.game.openpatrician.model.ship.EShipType;
import ch.sahits.game.openpatrician.model.ship.EShipUpgrade;
import ch.sahits.game.openpatrician.model.ship.ICog;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.PostConstruct;
import java.util.Properties;
@Prototype
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
public class Cog extends Ship implements ICog {
	@Autowired
	@XStreamOmitField
	private ShipProperties shipProperties;
	@Autowired
	@XStreamOmitField
	private ShipWeaponsLocationFactory weaponsLocationFactory;
	/**
	 * Constructor initializing the name and the upgrade level
	 * @param upgradeLevel
	 * @param name ships name
	 */
	public Cog(EShipUpgrade upgradeLevel, String name) {
		this.shipUpgradeLevel = upgradeLevel;
		this.name = name;
	}
	/**
	 * Constructor for a Crayer without any upgrade
	 * @param name
	 */
	public Cog(String name) {
		this(EShipUpgrade.NONE,name);
	}
	@PostConstruct
	private void init() {
		super.initializeProperties(shipProperties.getCog());
		setWeaponSlots(weaponsLocationFactory.getShipWeaponsLocation(EShipType.COG, shipUpgradeLevel));
	}
	@Override
	public EShipType getShipType() {
		return EShipType.COG;
	}

}

==> OpenPatricianModel-0.9.1-RC1-sources.jar: ch/sahits/game/openpatrician/model/ship/impl/Cog.java <==
package ch.sahits.game.openpatrician.model.ship.impl;

import ch.sahits.game.openpatrician.model.ship.EShipType;
import ch.sahits.game.openpatrician.model.ship.EShipUpgrade;
import ch.sahits.game.openpatrician.model.ship.ICog;
import ch.sahits.game.openpatrician.model.ship.ShipProperties;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.Prototype;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.PostConstruct;
@Prototype
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
public class Cog extends Ship implements ICog {
	@Autowired
	@XStreamOmitField
	private ShipProperties shipProperties;
	@Autowired
	@XStreamOmitField
	private ShipWeaponsLocationFactory weaponsLocationFactory;
	/**
	 * Constructor initializing the name and the upgrade level
	 * @param upgradeLevel upgrade level of the cog
	 * @param name ships name
	 */
	public Cog(EShipUpgrade upgradeLevel, String name) {
		this.shipUpgradeLevel = upgradeLevel;
		this.name = name;
	}
	/**
	 * Constructor for a Crayer without any upgrade
	 * @param name of the cog
	 */
	public Cog(String name) {
		this(EShipUpgrade.NONE,name);
	}
	@PostConstruct
	private void init() {
		super.initializeProperties(shipProperties.getCog());
		setWeaponSlots(weaponsLocationFactory.getShipWeaponsLocation(EShipType.COG, shipUpgradeLevel));
	}
	@Override
	public EShipType getShipType() {
		return EShipType.COG;
	}

}
